Trait orzir::verifiers::SameOperandAndResultTys
source · pub trait SameOperandAndResultTys: SameOperandTys + SameResultTys {
// Provided method
fn verify(&self, ctx: &Context) -> VerifyResult<()> { ... }
}Expand description
Verifier SameOperandAndResultTys for Op.
This verifier indicates that the results and the operands all share the same type. Note that the numbers of results and operands are not necessarily the same.